<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es_ES">
<context>
    <name>Editor::Internal::TableDialog</name>
    <message>
        <location filename="../../plugins/texteditorplugin/tabledialog.ui" line="23"/>
        <source>Table creation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tabledialog.ui" line="42"/>
        <source>Rich Text Editor Table Creator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tabledialog.ui" line="65"/>
        <source>Size of the table</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tabledialog.ui" line="83"/>
        <source>Number of columns</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tabledialog.ui" line="143"/>
        <source>Number of rows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tabledialog.ui" line="200"/>
        <source>Format of the table</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tabledialog.ui" line="218"/>
        <source>Cell spacing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tabledialog.ui" line="272"/>
        <source>Cell padding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tabledialog.ui" line="326"/>
        <source>Border</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tabledialog.ui" line="383"/>
        <source>Table headers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tabledialog.ui" line="395"/>
        <source>You can define the first row as header. The table header row get repeated when a table is broken across a page boundary.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tabledialog.ui" line="398"/>
        <source>Define the first row as header</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Editor::Internal::TablePropertiesDialog</name>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertiesdialog.ui" line="14"/>
        <location filename="../../plugins/texteditorplugin/tablepropertiesdialog.ui" line="32"/>
        <source>Rich Text - Table Properties</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Editor::Internal::TablePropertiesWidget</name>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.ui" line="24"/>
        <source>Border / Space</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.ui" line="30"/>
        <source>Border</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.ui" line="36"/>
        <source>Width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.ui" line="46"/>
        <source>Style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.ui" line="62"/>
        <source>Adjust column size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.ui" line="72"/>
        <source>Adjust row size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.ui" line="79"/>
        <source>Margins, Padding and spacing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.ui" line="99"/>
        <source>Margins (pix)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.ui" line="114"/>
        <source>Cell spacing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.ui" line="121"/>
        <source>Cell padding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.ui" line="141"/>
        <source>Colors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.ui" line="147"/>
        <source>Alterning rows color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.ui" line="154"/>
        <source>Border color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.ui" line="180"/>
        <source>Cells background color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="44"/>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="45"/>
        <source>Dotted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="46"/>
        <source>Dashed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="47"/>
        <source>Solid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="48"/>
        <source>Double</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="49"/>
        <source>Dot dash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="50"/>
        <source>Dot dot dash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="51"/>
        <source>Groove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="52"/>
        <source>Rigde</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="53"/>
        <source>Inset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="54"/>
        <source>Outset</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Editor::TextEditor</name>
    <message>
        <location filename="../../plugins/texteditorplugin/texteditor.cpp" line="500"/>
        <source>Save in pure textual format ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/texteditor.cpp" line="501"/>
        <source>The conversion of the document to a pure textual format will cause the lost of the paragraph and characters format. Do you really want to save in pure textual format ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/texteditorplugin/texteditor.cpp" line="523"/>
        <location filename="../../plugins/texteditorplugin/texteditor.cpp" line="525"/>
        <source>Font format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
